@@ -494,27 +494,27 @@ Col<eT>::subvec(const span& row_span) const
 
 
 
-// template<typename eT>
-// arma_inline
-// subview_col<eT>
-// Col<eT>::operator()(const span& row_span)
-//   {
-//   arma_extra_debug_sigprint();
-//   
-//   return subvec(row_span);
-//   }
-// 
-// 
-// 
-// template<typename eT>
-// arma_inline
-// const subview_col<eT>
-// Col<eT>::operator()(const span& row_span) const
-//   {
-//   arma_extra_debug_sigprint();
-//   
-//   return subvec(row_span);
-//   }
+template<typename eT>
+arma_inline
+subview_col<eT>
+Col<eT>::operator()(const span& row_span)
+  {
+  arma_extra_debug_sigprint();
+  
+  return subvec(row_span);
+  }
+
+
+
+template<typename eT>
+arma_inline
+const subview_col<eT>
+Col<eT>::operator()(const span& row_span) const
+  {
+  arma_extra_debug_sigprint();
+  
+  return subvec(row_span);
+  }
 
 
 
@@ -730,24 +730,6 @@ Col<eT>::end_row(const uword row_num) const
 
 
 
-template<typename eT>
-template<uword fixed_n_elem>
-arma_inline
-void
-Col<eT>::fixed<fixed_n_elem>::mem_setup()
-  {
-  arma_extra_debug_sigprint();
-  
-  access::rw(Mat<eT>::n_rows)    = fixed_n_elem;
-  access::rw(Mat<eT>::n_cols)    = 1;
-  access::rw(Mat<eT>::n_elem)    = fixed_n_elem;
-  access::rw(Mat<eT>::vec_state) = 1;
-  access::rw(Mat<eT>::mem_state) = 3;
-  access::rw(Mat<eT>::mem)       = (use_extra) ? mem_local_extra : Mat<eT>::mem_local;
-  }
-
-
-
 template<typename eT>
 template<uword fixed_n_elem>
 arma_inline
@@ -766,10 +748,9 @@ template<typename eT>
 template<uword fixed_n_elem>
 arma_inline
 Col<eT>::fixed<fixed_n_elem>::fixed()
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
   arma_extra_debug_sigprint_this(this);
-  
-  mem_setup();
   }
 
 
@@ -778,11 +759,10 @@ template<typename eT>
 template<uword fixed_n_elem>
 arma_inline
 Col<eT>::fixed<fixed_n_elem>::fixed(const fixed<fixed_n_elem>& X)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
   arma_extra_debug_sigprint_this(this);
   
-  mem_setup();
-  
   eT* dest = (use_extra) ? mem_local_extra : Mat<eT>::mem_local;
   
   arrayops::copy( dest, X.mem, fixed_n_elem );
@@ -794,11 +774,10 @@ template<typename eT>
 template<uword fixed_n_elem>
 inline
 Col<eT>::fixed<fixed_n_elem>::fixed(const subview_cube<eT>& X)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
   arma_extra_debug_sigprint_this(this);
   
-  mem_setup();
-  
   Col<eT>::operator=(X);
   }
 
@@ -809,11 +788,10 @@ template<uword fixed_n_elem>
 template<typename T1>
 inline
 Col<eT>::fixed<fixed_n_elem>::fixed(const Base<eT,T1>& A)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
   arma_extra_debug_sigprint_this(this);
   
-  mem_setup();
-  
   Col<eT>::operator=(A.get_ref());
   }
 
@@ -824,11 +802,10 @@ template<uword fixed_n_elem>
 template<typename T1, typename T2>
 inline
 Col<eT>::fixed<fixed_n_elem>::fixed(const Base<pod_type,T1>& A, const Base<pod_type,T2>& B)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
   arma_extra_debug_sigprint_this(this);
   
-  mem_setup();
-  
   Col<eT>::init(A,B);
   }
 
@@ -838,12 +815,13 @@ template<typename eT>
 template<uword fixed_n_elem>
 inline
 Col<eT>::fixed<fixed_n_elem>::fixed(const eT* aux_mem)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
   arma_extra_debug_sigprint_this(this);
   
-  mem_setup();
+  eT* dest = (use_extra) ? mem_local_extra : Mat<eT>::mem_local;
   
-  arrayops::copy( const_cast<eT*>(Mat<eT>::mem), aux_mem, fixed_n_elem );
+  arrayops::copy( dest, aux_mem, fixed_n_elem );
   }
 
 
@@ -855,11 +833,10 @@ template<typename eT>
 template<uword fixed_n_elem>
 inline
 Col<eT>::fixed<fixed_n_elem>::fixed(const char* text)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
   arma_extra_debug_sigprint_this(this);
   
-  mem_setup();
-  
   change_to_row();
   
   Col<eT>::operator=(text);
@@ -874,11 +851,10 @@ template<typename eT>
 template<uword fixed_n_elem>
 inline
 Col<eT>::fixed<fixed_n_elem>::fixed(const std::string& text)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
   arma_extra_debug_sigprint_this(this);
   
-  mem_setup();
-  
   change_to_row();
   
   Col<eT>::operator=(text);
@@ -961,15 +937,17 @@ Col<eT>::fixed<fixed_n_elem>::operator=(const subview_cube<eT>& X)
 
 
 
+#if defined(ARMA_USE_CXX11)
+
 template<typename eT>
 template<uword fixed_n_elem>
 inline
-subview_row<eT>
-Col<eT>::fixed<fixed_n_elem>::operator()(const uword row_num, const span& col_span)
+Col<eT>::fixed<fixed_n_elem>::fixed(const std::initializer_list<eT>& list)
+  : Col<eT>( arma_fixed_indicator(), fixed_n_elem, ((use_extra) ? mem_local_extra : Mat<eT>::mem_local) )
   {
-  arma_extra_debug_sigprint();
+  arma_extra_debug_sigprint_this(this);
   
-  return Mat<eT>::operator()(row_num, col_span);
+  (*this).operator=(list);
   }
 
 
@@ -977,66 +955,26 @@ Col<eT>::fixed<fixed_n_elem>::operator()(const uword row_num, const span& col_sp
 template<typename eT>
 template<uword fixed_n_elem>
 inline
-const subview_row<eT>
-Col<eT>::fixed<fixed_n_elem>::operator()(const uword row_num, const span& col_span) const
+const Col<eT>&
+Col<eT>::fixed<fixed_n_elem>::operator=(const std::initializer_list<eT>& list)
   {
   arma_extra_debug_sigprint();
   
-  return Mat<eT>::operator()(row_num, col_span);
-  }
-
-
-
-template<typename eT>
-template<uword fixed_n_elem>
-inline
-subview_col<eT>
-Col<eT>::fixed<fixed_n_elem>::operator()(const span& row_span, const uword col_num)
-  {
-  arma_extra_debug_sigprint();
+  const uword N = list.size();
   
-  return Mat<eT>::operator()(row_span, col_num);
-  }
-
-
-
-template<typename eT>
-template<uword fixed_n_elem>
-inline
-const subview_col<eT>
-Col<eT>::fixed<fixed_n_elem>::operator()(const span& row_span, const uword col_num) const
-  {
-  arma_extra_debug_sigprint();
+  arma_debug_check( (N > fixed_n_elem), "Col::fixed: initialiser list is too long" );
   
-  return Mat<eT>::operator()(row_span, col_num);
-  }
-
-
-
-template<typename eT>
-template<uword fixed_n_elem>
-inline
-subview<eT>
-Col<eT>::fixed<fixed_n_elem>::operator()(const span& row_span, const span& col_span)
-  {
-  arma_extra_debug_sigprint();
+  eT* this_mem = (*this).memptr();
   
-  return Mat<eT>::operator()(row_span, col_span);
-  }
-
-
-
-template<typename eT>
-template<uword fixed_n_elem>
-inline
-const subview<eT>
-Col<eT>::fixed<fixed_n_elem>::operator()(const span& row_span, const span& col_span) const
-  {
-  arma_extra_debug_sigprint();
+  arrayops::copy( this_mem, list.begin(), N );
   
-  return Mat<eT>::operator()(row_span, col_span);
+  for(uword iq=N; iq < fixed_n_elem; ++iq) { this_mem[iq] = eT(0); }
+  
+  return *this;
   }
 
+#endif
+
 
 
 template<typename eT>
@@ -1044,9 +982,9 @@ template<uword fixed_n_elem>
 arma_inline
 arma_warn_unused
 eT&
-Col<eT>::fixed<fixed_n_elem>::operator[] (const uword i)
+Col<eT>::fixed<fixed_n_elem>::operator[] (const uword ii)
   {
-  return (use_extra) ? mem_local_extra[i] : Mat<eT>::mem_local[i];
+  return (use_extra) ? mem_local_extra[ii] : Mat<eT>::mem_local[ii];
   }
 
 
@@ -1056,9 +994,9 @@ template<uword fixed_n_elem>
 arma_inline
 arma_warn_unused
 eT
-Col<eT>::fixed<fixed_n_elem>::operator[] (const uword i) const
+Col<eT>::fixed<fixed_n_elem>::operator[] (const uword ii) const
   {
-  return (use_extra) ? mem_local_extra[i] : Mat<eT>::mem_local[i];
+  return (use_extra) ? mem_local_extra[ii] : Mat<eT>::mem_local[ii];
   }
 
 
@@ -1068,9 +1006,9 @@ template<uword fixed_n_elem>
 arma_inline
 arma_warn_unused
 eT&
-Col<eT>::fixed<fixed_n_elem>::at(const uword i)
+Col<eT>::fixed<fixed_n_elem>::at(const uword ii)
   {
-  return (use_extra) ? mem_local_extra[i] : Mat<eT>::mem_local[i];
+  return (use_extra) ? mem_local_extra[ii] : Mat<eT>::mem_local[ii];
   }
 
 
@@ -1080,9 +1018,9 @@ template<uword fixed_n_elem>
 arma_inline
 arma_warn_unused
 eT
-Col<eT>::fixed<fixed_n_elem>::at(const uword i) const
+Col<eT>::fixed<fixed_n_elem>::at(const uword ii) const
   {
-  return (use_extra) ? mem_local_extra[i] : Mat<eT>::mem_local[i];
+  return (use_extra) ? mem_local_extra[ii] : Mat<eT>::mem_local[ii];
   }
 
 
@@ -1092,11 +1030,11 @@ template<uword fixed_n_elem>
 arma_inline
 arma_warn_unused
 eT&
-Col<eT>::fixed<fixed_n_elem>::operator() (const uword i)
+Col<eT>::fixed<fixed_n_elem>::operator() (const uword ii)
   {
-  arma_debug_check( (i >= fixed_n_elem), "Col::operator(): out of bounds");
+  arma_debug_check( (ii >= fixed_n_elem), "Col::operator(): out of bounds");
   
-  return (use_extra) ? mem_local_extra[i] : Mat<eT>::mem_local[i];
+  return (use_extra) ? mem_local_extra[ii] : Mat<eT>::mem_local[ii];
   }
 
 
@@ -1106,11 +1044,11 @@ template<uword fixed_n_elem>
 arma_inline
 arma_warn_unused
 eT
-Col<eT>::fixed<fixed_n_elem>::operator() (const uword i) const
+Col<eT>::fixed<fixed_n_elem>::operator() (const uword ii) const
   {
-  arma_debug_check( (i >= fixed_n_elem), "Col::operator(): out of bounds");
+  arma_debug_check( (ii >= fixed_n_elem), "Col::operator(): out of bounds");
   
-  return (use_extra) ? mem_local_extra[i] : Mat<eT>::mem_local[i];
+  return (use_extra) ? mem_local_extra[ii] : Mat<eT>::mem_local[ii];
   }
 
 
@@ -1245,6 +1183,16 @@ Col<eT>::fixed<fixed_n_elem>::ones()
 
 
 
+template<typename eT>
+inline
+Col<eT>::Col(const arma_fixed_indicator&, const uword in_n_elem, const eT* in_mem)
+  : Mat<eT>(arma_fixed_indicator(), in_n_elem, 1, 1, in_mem)
+  {
+  arma_extra_debug_sigprint_this(this);
+  }
+
+
+
 #ifdef ARMA_EXTRA_COL_MEAT
   #include ARMA_INCFILE_WRAP(ARMA_EXTRA_COL_MEAT)
 #endif
