@@ -27,7 +27,6 @@ class Row : public Mat<eT>
   static const bool is_col = false;
   static const bool is_row = true;
   
-  
   inline          Row();
   inline          Row(const Row<eT>& X);
   inline explicit Row(const uword N);
@@ -44,6 +43,7 @@ class Row : public Mat<eT>
   inline const Row& operator=(const std::initializer_list<eT>& list);
   #endif
   
+  
   inline const Row& operator=(const eT val);
 
   template<typename T1> inline                   Row(const Base<eT,T1>& X);
@@ -79,8 +79,10 @@ class Row : public Mat<eT>
   arma_inline       subview_row<eT> subvec(const span& col_span);
   arma_inline const subview_row<eT> subvec(const span& col_span) const;
   
-  // arma_inline       subview_row<eT> operator()(const span& col_span);
-  // arma_inline const subview_row<eT> operator()(const span& col_span) const;
+  using Mat<eT>::operator();
+  
+  arma_inline       subview_row<eT> operator()(const span& col_span);
+  arma_inline const subview_row<eT> operator()(const span& col_span) const;
   
   
   inline void shed_col (const uword col_num);
@@ -116,8 +118,6 @@ class Row : public Mat<eT>
     
     arma_aligned eT mem_local_extra[ (use_extra) ? fixed_n_elem : 1 ];
     
-    arma_inline void mem_setup();
-    
     
     public:
     
@@ -152,14 +152,12 @@ class Row : public Mat<eT>
     inline const Row& operator=(const std::string& text);
     inline const Row& operator=(const subview_cube<eT>& X);
     
-    inline       subview_row<eT> operator()(const uword   row_num,  const span& col_span);
-    inline const subview_row<eT> operator()(const uword   row_num,  const span& col_span) const;
+    using Row<eT>::operator();
     
-    inline       subview_col<eT> operator()(const span& row_span, const uword   col_num );
-    inline const subview_col<eT> operator()(const span& row_span, const uword   col_num ) const;
-    
-    inline       subview<eT>     operator()(const span& row_span, const span& col_span);
-    inline const subview<eT>     operator()(const span& row_span, const span& col_span) const;
+    #if defined(ARMA_USE_CXX11)
+    inline                fixed(const std::initializer_list<eT>& list);
+    inline const Row& operator=(const std::initializer_list<eT>& list);
+    #endif
     
     arma_inline arma_warn_unused eT& operator[] (const uword i);
     arma_inline arma_warn_unused eT  operator[] (const uword i) const;
@@ -182,10 +180,16 @@ class Row : public Mat<eT>
     };
   
   
+  protected:
+  
+  inline Row(const arma_fixed_indicator&, const uword in_n_elem, const eT* in_mem);
+  
+  
+  public:
+  
   #ifdef ARMA_EXTRA_ROW_PROTO
     #include ARMA_INCFILE_WRAP(ARMA_EXTRA_ROW_PROTO)
   #endif
-  
   };
 
 
