@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2011 Conrad Sanderson
+// Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2012 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -65,10 +65,26 @@ arma_ostream::modify_stream(std::ostream& o, const eT* data, const uword n_elem)
     const eT val = data[i];
     
     if(
-      val >= eT(+100) ||
-      ( (is_signed<eT>::value == true) && (val <= eT(-100)) ) ||
-      ( (is_non_integral<eT>::value == true) && (val > eT(0)) && (val <= eT(+1e-4)) ) ||
-      ( (is_non_integral<eT>::value == true) && (is_signed<eT>::value == true) && (val < eT(0)) && (val >= eT(-1e-4)) ) 
+      ( val >= eT(+100) )
+      ||
+      //( (is_signed<eT>::value == true) && (val <= eT(-100)) ) ||
+      //( (is_non_integral<eT>::value == true) && (val > eT(0)) && (val <= eT(+1e-4)) ) ||
+      //( (is_non_integral<eT>::value == true) && (is_signed<eT>::value == true) && (val < eT(0)) && (val >= eT(-1e-4)) ) 
+        (
+        cond_rel< is_signed<eT>::value >::leq(val, eT(-100))
+        )
+      ||
+        (
+        cond_rel< is_non_integral<eT>::value >::gt(val,  eT(0))
+        &&
+        cond_rel< is_non_integral<eT>::value >::leq(val, eT(+1e-4))
+        )
+      ||
+        (
+        cond_rel< is_non_integral<eT>::value && is_signed<eT>::value >::lt(val, eT(0))
+        &&
+        cond_rel< is_non_integral<eT>::value && is_signed<eT>::value >::geq(val, eT(-1e-4))
+        )
       )
       {
       use_layout_C = true;
@@ -76,7 +92,8 @@ arma_ostream::modify_stream(std::ostream& o, const eT* data, const uword n_elem)
       }
       
     if(
-      (val >= eT(+10)) || ( (is_signed<eT>::value == true) && (val <= eT(-10)) )
+      // (val >= eT(+10)) || ( (is_signed<eT>::value == true) && (val <= eT(-10)) )
+      (val >= eT(+10)) || ( cond_rel< is_signed<eT>::value >::leq(val, eT(-10)) )
       )
       {
       use_layout_B = true;
