@@ -16,42 +16,6 @@
 
 
 
-class eglue_plus : public eglue_core<eglue_plus>
-  {
-  public:
-  
-  inline static const char* text() { return "addition"; }
-  };
-
-
-
-class eglue_minus : public eglue_core<eglue_minus>
-  {
-  public:
-  
-  inline static const char* text() { return "subtraction"; }
-  };
-
-
-
-class eglue_div : public eglue_core<eglue_div>
-  {
-  public:
-  
-  inline static const char* text() { return "element-wise division"; }
-  };
-
-
-
-class eglue_schur : public eglue_core<eglue_schur>
-  {
-  public:
-  
-  inline static const char* text() { return "element-wise multiplication"; }
-  };
-
-
-
 #undef arma_applier_1
 #undef arma_applier_2
 #undef arma_applier_3
@@ -189,11 +153,13 @@ eglue_core<eglue_type>::apply(Mat<typename T1::elem_type>& out, const eGlue<T1,
   // NOTE: we're assuming that the matrix has already been set to the correct size and there is no aliasing;
   // size setting and alias checking is done by either the Mat contructor or operator=()
   
+  
   eT* out_mem = out.memptr();
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem = out.n_elem;
+    // for fixed-sized vectors with n_elem >= 6, using x.get_n_elem() directly causes a mis-optimisation (slowdown) of the loop under GCC 4.4
+    const uword n_elem = (Proxy<T1>::is_fixed || Proxy<T2>::is_fixed) ? ( (x.get_n_elem() <= 4) ? x.get_n_elem() : out.n_elem ) : out.n_elem;
     
     typename Proxy<T1>::ea_type P1 = x.P1.get_ea();
     typename Proxy<T2>::ea_type P2 = x.P2.get_ea();
@@ -242,7 +208,8 @@ eglue_core<eglue_type>::apply_inplace_plus(Mat<typename T1::elem_type>& out, con
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem = out.n_elem;
+    // for fixed-sized vectors with n_elem >= 6, using x.get_n_elem() directly causes a mis-optimisation (slowdown) of the loop under GCC 4.4
+    const uword n_elem = (Proxy<T1>::is_fixed || Proxy<T2>::is_fixed) ? ( (x.get_n_elem() <= 4) ? x.get_n_elem() : out.n_elem ) : out.n_elem;
     
     typename Proxy<T1>::ea_type P1 = x.P1.get_ea();
     typename Proxy<T2>::ea_type P2 = x.P2.get_ea();
@@ -288,7 +255,8 @@ eglue_core<eglue_type>::apply_inplace_minus(Mat<typename T1::elem_type>& out, co
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem = out.n_elem;
+    // for fixed-sized vectors with n_elem >= 6, using x.get_n_elem() directly causes a mis-optimisation (slowdown) of the loop under GCC 4.4
+    const uword n_elem = (Proxy<T1>::is_fixed || Proxy<T2>::is_fixed) ? ( (x.get_n_elem() <= 4) ? x.get_n_elem() : out.n_elem ) : out.n_elem;
     
     typename Proxy<T1>::ea_type P1 = x.P1.get_ea();
     typename Proxy<T2>::ea_type P2 = x.P2.get_ea();
@@ -334,7 +302,8 @@ eglue_core<eglue_type>::apply_inplace_schur(Mat<typename T1::elem_type>& out, co
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem = out.n_elem;
+    // for fixed-sized vectors with n_elem >= 6, using x.get_n_elem() directly causes a mis-optimisation (slowdown) of the loop under GCC 4.4
+    const uword n_elem = (Proxy<T1>::is_fixed || Proxy<T2>::is_fixed) ? ( (x.get_n_elem() <= 4) ? x.get_n_elem() : out.n_elem ) : out.n_elem;
     
     typename Proxy<T1>::ea_type P1 = x.P1.get_ea();
     typename Proxy<T2>::ea_type P2 = x.P2.get_ea();
@@ -380,7 +349,8 @@ eglue_core<eglue_type>::apply_inplace_div(Mat<typename T1::elem_type>& out, cons
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem = out.n_elem;
+    // for fixed-sized vectors with n_elem >= 6, using x.get_n_elem() directly causes a mis-optimisation (slowdown) of the loop under GCC 4.4
+    const uword n_elem = (Proxy<T1>::is_fixed || Proxy<T2>::is_fixed) ? ( (x.get_n_elem() <= 4) ? x.get_n_elem() : out.n_elem ) : out.n_elem;
     
     typename Proxy<T1>::ea_type P1 = x.P1.get_ea();
     typename Proxy<T2>::ea_type P2 = x.P2.get_ea();
@@ -434,7 +404,7 @@ eglue_core<eglue_type>::apply(Cube<typename T1::elem_type>& out, const eGlueCube
     
     typename ProxyCube<T1>::ea_type P1 = x.P1.get_ea();
     typename ProxyCube<T2>::ea_type P2 = x.P2.get_ea();
-  
+    
          if(is_same_type<eglue_type, eglue_plus >::value == true) { arma_applier_1(=, +); }
     else if(is_same_type<eglue_type, eglue_minus>::value == true) { arma_applier_1(=, -); }
     else if(is_same_type<eglue_type, eglue_div  >::value == true) { arma_applier_1(=, /); }
@@ -481,7 +451,7 @@ eglue_core<eglue_type>::apply_inplace_plus(Cube<typename T1::elem_type>& out, co
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem  = out.n_elem;
+    const uword n_elem = out.n_elem;
     
     typename ProxyCube<T1>::ea_type P1 = x.P1.get_ea();
     typename ProxyCube<T2>::ea_type P2 = x.P2.get_ea();
@@ -528,7 +498,7 @@ eglue_core<eglue_type>::apply_inplace_minus(Cube<typename T1::elem_type>& out, c
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem  = out.n_elem;
+    const uword n_elem = out.n_elem;
     
     typename ProxyCube<T1>::ea_type P1 = x.P1.get_ea();
     typename ProxyCube<T2>::ea_type P2 = x.P2.get_ea();
@@ -575,7 +545,7 @@ eglue_core<eglue_type>::apply_inplace_schur(Cube<typename T1::elem_type>& out, c
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem  = out.n_elem;
+    const uword n_elem = out.n_elem;
     
     typename ProxyCube<T1>::ea_type P1 = x.P1.get_ea();
     typename ProxyCube<T2>::ea_type P2 = x.P2.get_ea();
@@ -622,7 +592,7 @@ eglue_core<eglue_type>::apply_inplace_div(Cube<typename T1::elem_type>& out, con
   
   if(prefer_at_accessor == false)
     {
-    const uword n_elem  = out.n_elem;
+    const uword n_elem = out.n_elem;
     
     typename ProxyCube<T1>::ea_type P1 = x.P1.get_ea();
     typename ProxyCube<T2>::ea_type P2 = x.P2.get_ea();
