@@ -361,28 +361,40 @@ op_cdot::apply(const Base<typename T1::elem_type,T1>& X, const Base<typename T1:
   const Proxy<T1> A(X.get_ref());
   const Proxy<T2> B(Y.get_ref());
   
-  arma_debug_check( (A.get_n_elem() != B.get_n_elem()), "cdot(): objects must have the same number of elements" );
+  const bool prefer_at_accessor = (Proxy<T1>::prefer_at_accessor) || (Proxy<T2>::prefer_at_accessor);
   
-  const uword    N  = A.get_n_elem();
-        ea_type1 PA = A.get_ea();
-        ea_type2 PB = B.get_ea();
-  
-  eT val1 = eT(0);
-  eT val2 = eT(0);
-  
-  uword i,j;
-  for(i=0, j=1; j<N; i+=2, j+=2)
+  if(prefer_at_accessor == false)
     {
-    val1 += std::conj(PA[i]) * PB[i];
-    val2 += std::conj(PA[j]) * PB[j];
+    arma_debug_check( (A.get_n_elem() != B.get_n_elem()), "cdot(): objects must have the same number of elements" );
+    
+    const uword    N  = A.get_n_elem();
+          ea_type1 PA = A.get_ea();
+          ea_type2 PB = B.get_ea();
+    
+    eT val1 = eT(0);
+    eT val2 = eT(0);
+    
+    uword i,j;
+    for(i=0, j=1; j<N; i+=2, j+=2)
+      {
+      val1 += std::conj(PA[i]) * PB[i];
+      val2 += std::conj(PA[j]) * PB[j];
+      }
+    
+    if(i < N)
+      {
+      val1 += std::conj(PA[i]) * PB[i];
+      }
+    
+    return val1 + val2;
     }
-  
-  if(i < N)
+  else
     {
-    val1 += std::conj(PA[i]) * PB[i];
+    const unwrap< typename Proxy<T1>::stored_type > tmp_A(A.Q);
+    const unwrap< typename Proxy<T2>::stored_type > tmp_B(B.Q);
+    
+    return op_cdot::apply( tmp_A.M, tmp_B.M );
     }
-  
-  return val1 + val2;
   }
 
 
